package com.grail.archives.controller;

import com.alibaba.fastjson.JSON;
import com.grail.common.core.domain.R;
import com.grail.common.core.domain.Result;
import com.grail.domain.model.Archives;
import com.grail.domain.request.ArchivesRequest;
import com.grail.domain.request.Vo;
import com.grail.archives.service.ArchivesService;
import com.grail.domain.response.ArchivesResponse;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Author：shixuchao
 * @Date：
 * @Description 档案controller
 */
@RestController
@RequestMapping("/archives")
@Log4j2
public class ArchivesController {

    @Autowired
    private HttpServletRequest request;

    @Autowired
    private ArchivesService archivesService;

    //展示我的档案信息
    @PostMapping("/archivesList")
    private R archivesList(@RequestBody Vo vo){
        R archives=archivesService.archivesList(vo);
        log.info("功能：我的展示档案列表:URI:{},方法:{},信息:{}",request.getRequestURI()
                ,request.getMethod(), JSON.toJSONString(archives.getData()));
        return R.ok(archives);
    }

    //添加我的档案
    @PostMapping("/archivesInsert")
    private R archivesInsert(@RequestBody ArchivesResponse archives){
        R result=archivesService.archivesInsert(archives);
        log.info("功能：添加档案，URI:{},方法:{},信息:{}",request.getRequestURI(),request.getMethod()
        ,JSON.toJSONString(result.getData()));
        return result;
    }

    //修改我的档案
    @PostMapping("/archivesUpdate")
    private R archivesUpdate(@RequestBody Archives archives){
        R result=archivesService.archivesUpdate(archives);
        log.info("功能：修改我的档案，URI:{},方法:{},参数:{}",request.getRequestURI()
        ,request.getMethod(),JSON.toJSONString(result.getData()));
        return result;
    }

    //删除我的档案信息
    @DeleteMapping("/archivesDelete/{archivesId}")
    private R archivesDelete(@PathVariable Integer archivesId){
        R result=archivesService.archivesDelete(archivesId);
        log.info("功能：删除我的档案:URI:{},方法:{},参数:{}",request.getRequestURI()
        ,request.getMethod(),JSON.toJSONString(result.getData()));
        return result;
    }

    //回显我的档案信息
    @PostMapping("/archivesFind/{archivesId}")
    private R archivesFind(@PathVariable Integer archivesId){
        R result=archivesService.archivesFind(archivesId);
        log.info("功能回显我的档案信息：URI：{} 方法：{} 参数：{}",request.getRequestURI(),request.getMethod()
        ,JSON.toJSONString(result.getData()));
        return result;
    }

}
